@@ -22,6 +22,7 @@ def test_attributes(h: Html):
 def test_attributes_name_mangling(h: Html):
     assert str(h.span(class_="myclass")) == '<span class="myclass"></span>'
     assert str(h.span(data_foo="bar")) == '<span data-foo="bar"></span>'
+    assert str(h.span(_="quux")) == '<span _="quux"></span>'
 
 
 def test_name_only_attributes(h: Html):
@@ -72,4 +73,4 @@ def test_tostring(h: Html):
 
 
 def test_tag_repr(h: Html):
-    assert repr(h.p("hi")) == "<MixedTag 'p'>"
+    assert repr(h.p("hi")) == "<MixedElement 'p'>"
